@@ -1,7 +1,7 @@
 use std::io::{self, Write};
 
 use rustc_hash::FxHashSet;
-use swc_common::{sync::Lrc, BytePos, LineCol, SourceMap, Span, DUMMY_SP};
+use swc_common::{sync::Lrc, BytePos, LineCol, SourceMap, Span};
 use swc_ecma_ast::EsVersion;
 
 use super::{Result, WriteJs};
